vim.g.mapleader = ' '
vim.g.maplocalleader = ' '

local opts = { silent = true, noremap = true }

vim.api.nvim_set_keymap('n', '<C-h>', ':NvimTreeToggle<cr>', {silent = true, noremap = true})

-- Increment/decrement
vim.keymap.set('n', '+', '<C-a>')
vim.keymap.set('n', '-', '<C-x>')

-- Select all
vim.keymap.set('n', '<C-a>', 'gg<S-v>G')

-- Split window
vim.keymap.set('n', '<leader>ss', '<Cmd>split<CR>', opts)
vim.keymap.set('n', '<leader>sv', '<Cmd>vsplit<CR>', opts)

-- Fast save
vim.keymap.set('n', '<leader>w', ':w!<cr>', opts)

vim.keymap.set('n', '<leader>n', ':NvimTreeToggle<cr>', opts)

vim.keymap.set('n', '<leader><space>', ':noh<cr>', opts)

-- Remap, because % is mapped to matchit
vim.keymap.set({ 'n', 'v' }, '<tab>', '%', { silent = true, remap = true })

vim.keymap.set('n', '<leader>S', ':%s//<left>', opts)
vim.keymap.set('v', '<leader>S', ':s//<left>', opts)

-- use enter/backspace to add/remove lines in normal mode
-- New line without entering insert mode
vim.keymap.set('n', '<CR>', 'o<Esc>k', opts)
vim.keymap.set('n', '<S-CR>', 'ko<Esc>j', opts)
vim.keymap.set('n', '<Backspace>', 'ddk', opts)

-- Do not fill the yank register with single chars
vim.keymap.set('n', 'x', '"_x', opts)
vim.keymap.set('n', 'X', '"_X', opts)

-- Better line joining
vim.keymap.set('n', 'J', 'mzJ`z')

-- Lazy
vim.keymap.set('n', '<leader>l', '<Cmd>Lazy<CR>', opts)

-- Move lines in visual mode
vim.keymap.set('v', 'J', ":m '>+1<CR>gv=gv")
vim.keymap.set('v', 'K', ":m '<-2<CR>gv=gv")

-- Buffers
vim.keymap.set('n', '<A-,>', '<Cmd>BufferPrevious<CR>', opts)
vim.keymap.set('n', '<A-.>', '<Cmd>BufferNext<CR>', opts)

vim.keymap.set('n', '<A-<>', '<Cmd>BufferMovePrevious<CR>', opts)
vim.keymap.set('n', '<A->>', '<Cmd>BufferMoveNext<CR>', opts)
vim.keymap.set('n', '<A-p>', '<Cmd>BufferPin<CR>', opts)
vim.keymap.set('n', '<A-w>', '<Cmd>BufferClose<CR>', opts)

vim.keymap.set('n', '<A-1>', '<Cmd>BufferGoto 1<CR>', opts)
vim.keymap.set('n', '<A-2>', '<Cmd>BufferGoto 2<CR>', opts)
vim.keymap.set('n', '<A-3>', '<Cmd>BufferGoto 3<CR>', opts)
vim.keymap.set('n', '<A-4>', '<Cmd>BufferGoto 4<CR>', opts)
vim.keymap.set('n', '<A-5>', '<Cmd>BufferGoto 5<CR>', opts)
vim.keymap.set('n', '<A-6>', '<Cmd>BufferGoto 6<CR>', opts)
vim.keymap.set('n', '<A-7>', '<Cmd>BufferGoto 7<CR>', opts)
vim.keymap.set('n', '<A-8>', '<Cmd>BufferGoto 8<CR>', opts)
vim.keymap.set('n', '<A-9>', '<Cmd>BufferGoto 9<CR>', opts)
vim.keymap.set('n', '<A-0>', '<Cmd>BufferLast<CR>', opts)

-- Telescope
vim.keymap.set('n', '<leader>ff', '<Cmd>Telescope find_files<CR>', { desc = 'Telescope find files' })
vim.keymap.set('n', '<leader>fg', '<Cmd>Telescope live_grep<CR>', { desc = 'Telescope live grep' })
vim.keymap.set('n', '<leader>fb', '<Cmd>Telescope buffers<CR>', { desc = 'Telescope buffers' })
vim.keymap.set('n', '<leader>fh', '<Cmd>Telescope help_tags<CR>', { desc = 'Telescope help tags' })
